Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(671)

Unified Diff: runtime/lib/object.cc

Issue 2684963004: Move _fatal to dart:async (Closed)
Patch Set: Restore the original behavior Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/lib/internal_patch.dart ('k') | runtime/vm/bootstrap_natives.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/lib/object.cc
diff --git a/runtime/lib/object.cc b/runtime/lib/object.cc
index 9c20eebdab0c2e4febc27a6f9d4907a57448c147..e5cb7e1c6a07686d4ff8097bcc8111d8a6e33f79 100644
--- a/runtime/lib/object.cc
+++ b/runtime/lib/object.cc
@@ -20,11 +20,11 @@ DECLARE_FLAG(bool, trace_type_checks);
// Helper function in stacktrace.cc.
void _printCurrentStackTrace();
-DEFINE_NATIVE_ENTRY(DartInternal_fatal, 1) {
- // The SDK library code entered an unrecoverable state.
+DEFINE_NATIVE_ENTRY(DartAsync_fatal, 1) {
+ // The dart:async library code entered an unrecoverable state.
const Instance& instance = Instance::CheckedHandle(arguments->NativeArgAt(0));
const char* msg = instance.ToCString();
- OS::PrintErr("Fatal error in the SDK libraries\n");
+ OS::PrintErr("Fatal error in dart:async: %s\n", msg);
_printCurrentStackTrace();
FATAL(msg);
return Object::null();
« no previous file with comments | « runtime/lib/internal_patch.dart ('k') | runtime/vm/bootstrap_natives.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698